@@ -2,7 +2,11 @@
 
 from __future__ import annotations
 
-from griffe.dataclasses import Function, Parameter, Parameters
+import inspect
+
+import pytest
+
+from griffe.dataclasses import Class, Function, Module, Parameter, Parameters
 from griffe.docstrings import google
 from griffe.docstrings.dataclasses import DocstringSectionKind
 from tests.test_docstrings.helpers import parser
@@ -32,25 +36,6 @@ def test_multiline_docstring():
     assert not warnings
 
 
-def test_unknown_matching_admonitions():
-    """Properly handle offset when matching an unknown admonition (line ending with `:`)."""
-    docstring = """
-        First line.
-
-        Matching but unknown admonition type:
-
-        - Some list items
-
-        Ending line.
-    """
-    sections, warnings = parse(docstring)
-    assert len(sections) == 1
-    assert sections[0].kind is DocstringSectionKind.text
-    # -2 because docstring is stripped
-    assert len(sections[0].value.splitlines()) == len(docstring.splitlines()) - 2
-    assert not warnings
-
-
 def test_parse_partially_indented_lines():
     """Properly handle partially indented lines."""
     docstring = """
@@ -700,3 +685,70 @@ def test_parse_admonitions():
     assert sections[2].title == "Something"
     assert sections[2].value.kind == "something"
     assert sections[2].value.contents == "Something."
+
+
+@pytest.mark.parametrize(
+    "docstring",
+    [
+        """
+        ******************************
+        This looks like an admonition:
+        ******************************
+        """,
+        """
+        Warning: this line also looks
+        like an admonition.
+        """,
+        """
+        Matching but not an admonition:
+
+
+
+        - Multiple empty lines above.
+        """,
+        """Last line:""",
+    ],
+)
+def test_handle_false_admonitions_correctly(docstring):
+    """Correctly handle lines that look like admonitions.
+
+    Parameters:
+        docstring: The docstring to parse (parametrized).
+    """
+    sections, warnings = parse(docstring)
+    assert len(sections) == 1
+    assert sections[0].kind is DocstringSectionKind.text
+    assert len(sections[0].value.splitlines()) == len(inspect.cleandoc(docstring).splitlines())
+    assert not warnings
+
+
+@pytest.mark.parametrize(
+    "docstring",
+    [
+        "",
+        "\n",
+        "\n\n",
+        "Summary.",
+        "Summary.\n\n\n",
+        "Summary.\n\nParagraph.",
+        "Summary\non two lines.",
+        "Summary\non two lines.\n\nParagraph.",
+    ],
+)
+def test_ignore_init_summary(docstring):
+    """Correctly ignore summary in `__init__` methods' docstrings.
+
+    Parameters:
+        docstring: The docstring to parse (parametrized).
+    """
+    sections, _ = parse(docstring, parent=Function("__init__", parent=Class("C")), ignore_init_summary=True)
+    for section in sections:
+        assert "Summary" not in section.value
+
+    if docstring.strip():
+        sections, _ = parse(docstring, parent=Function("__init__", parent=Module("M")), ignore_init_summary=True)
+        assert "Summary" in sections[0].value
+        sections, _ = parse(docstring, parent=Function("f", parent=Class("C")), ignore_init_summary=True)
+        assert "Summary" in sections[0].value
+        sections, _ = parse(docstring, ignore_init_summary=True)
+        assert "Summary" in sections[0].value
